@@ -37,12 +37,6 @@ Creates a new C<Sys::IO::Stat> object.
 
 If $path is specified, L</"stat"> is called.
 
-=head2 stat_raw
-
-C<static method stat_raw : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
-
-The same as L</"stat">, but even if the return value is C<-1>, an exception will not be thrown.
-
 =head2 stat
 
 C<static method stat : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
@@ -55,12 +49,6 @@ See the L<stat|https://linux.die.net/man/2/stat> function in Linux.
 
 The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
-=head2 lstat_raw
-
-C<static method lstat_raw : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
-
-The same as L</"lstat">, but even if the return value is C<-1>, an exception will not be thrown.
-
 =head2 lstat
 
 C<static method lstat : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
@@ -73,12 +61,6 @@ See the L<lstat|https://linux.die.net/man/2/lstat> function in Linux.
 
 The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
-=head2 fstat_raw
-
-C<static method fstat_raw : int ($fd : int, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
-
-The same as L</"fstat">, but even if the return value is C<-1>, an exception will not be thrown.
-
 =head2 fstat
 
 C<static method fstat : int ($fd : int, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
