@@ -12,29 +12,15 @@ SPVM::Sys::Signal - Signal System Call
   use Sys::Signal::Constant as SIGNAL;
   
   Sys::Signal->raise(SIGNAL->SIGTERM);
-
+  
   Sys::Signal->kill($process_id, SIGNAL->SIGINT);
-
-  Sys::Signal->signal(SIGNAL->SIGTERM, Sys::Signal->SIG_IGN);
+  
+  my $old_signal_handler = Sys::Signal->signal(SIGNAL->SIGTERM, Sys::Signal->SIG_IGN);
 
 =head1 Description
 
 C<Sys::Signal> provides the methods to call the system call for the signal.
 
-=head1 Class Variables
-
-=head2 $SIG_DFL
-
-  our $SIG_DFL : ro Sys::Signal::Handler::Default;
-
-Gets a singlton L<Sys::Signal::Handler::Default|SPVM::Sys::Signal::Handler::Default> object that represents C<SIG_DFL> in C<C Language>.
-
-=head2 $SIG_IGN
-
-  our $SIG_IGN : ro Sys::Signal::Handler::Ignore;
-
-Gets a singlton L<Sys::Signal::Handler::Ignore|SPVM::Sys::Signal::Handler::Ignore> object that represents C<SIG_IGN> in C<C Language>.
-
 =head1 Class Methods
 
 =head2 raise
@@ -85,13 +71,35 @@ See L<signal(2) - Linux man page|https://linux.die.net/man/2/signal> in Linux.
 
 Constant values specified in C<$signum> is defined in L<Sys::Signal::Constant|SPVM::Sys::Signal::Constant>.
 
-The C<$handler> must be a L<Sys::Signal::Handler::Default|SPVM::Sys::Signal::Handler::Default> object or a L<Sys::Signal::Handler::Ignore|SPVM::Sys::Signal::Handler::Ignore> object
-
 Exceptions:
 
 $handler must be defined. Otherwise an exception is thrown.
 
-$handler must be a Sys::Signal::Handler::Default object or a Sys::Signal::Handler::Ignore object. Otherwise an exception is thrown.
+=head2 signal_io
+
+C<static method signal_io : Sys::Signal::Handler ($signum : int, $fd : int);>
+
+signal() sets the disposition of the signal signum to L</"SIG_IO"> handler with a file descriptor a signal is written.
+
+Returns the old signal handler.
+
+=head2 SIG_DFL
+
+  static method SIG_DFL : L<Sys::Signal::Handler|SPVM::Sys::Signal::Handler> ()
+
+Creates a new signal handler that represents C<SIG_DFL>.
+
+=head2 SIG_IGN
+
+  static method SIG_IGN : L<Sys::Signal::Handler|SPVM::Sys::Signal::Handler> ();
+
+Creates a new signal handler that represents C<SIG_IGN>.
+
+=head2 SIG_IO
+
+  static method SIG_IO : L<Sys::Signal::Handler|SPVM::Sys::Signal::Handler> ();
+
+Creates a new signal handler that represents writing a signale to a file descriptor.
 
 =head1 Copyright & License
 
